==> evolution-1.4.11.zip: evolution-1.4.11/manager/includes/lang/errormsg/italian.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Italian
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Nessun errore.";
$_lang["An error occured!"] = "Si è verificato un errore!";
$_lang["You don't have enough privileges for this action!"] = "Non avete i diritti necessari per effettuare questa operazione!";
$_lang["ID passed in request is NaN!"] = "L'ID passato nella richiesta è NaN!";
$_lang["The document is locked!"] = "Il documento è bloccato!";
$_lang["Too many results returned from database!"] = "Sono stati trovati troppi risultati nel database!";
$_lang["Not enough/ no results returned from database!"] = "Sono stati trovati pochi risultati (o nessuno) nel database!";
$_lang["Couldn't find parent document's name!"] = "Impossibile trovare il nome del documento genitore!";
$_lang["Logging error!"] = "Errore nell'accesso!";
$_lang["Table to optimise not found in request!"] = "Impossibile trovare la tabella da ottimizzare!";
$_lang["No settings found in request!"] = "La richiesta non contiene impostazioni!";
$_lang["The document must have a title!"] = "Il documento deve avere un titolo!";
$_lang["No user selected as recipient of this message!"] = "Non è stato selezionato l'utente a cui inviare questo messaggio!";
$_lang["No group selected as recipient of this message!"] = "Non è stato selezionato il gruppo a cui inviare questo messaggio!";
$_lang["The document was not found!"] = "Impossibile trovare il documento!";
$_lang["Double action (GET & POST) posted!"] = "E' stata inviata una doppia azione (GET e POST)!";
$_lang["Document cannot be it's own parent!"] = "Il documento non può essere genitore di se stesso!";
$_lang["Document's ID not passed in request!"] = "Nella richiesta manca l'ID del documento!";
$_lang["New parent not set in request!"] = "Nella richiesta non è stato indicato il nuovo genitore!";
$_lang["don't know the user!" ] = "Username o password errati!";
$_lang["wrong password!"] = "Username o password errati!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Accesso bloccato a causa di troppi tentativi falliti!";
$_lang["You are blocked and cannot log in!"] = "Impossibile accedere, l'accesso è stato bloccato!";
$_lang["You are blocked and cannot log in! Please try again later."] = "L'accesso è stato bloccato! Riprovare più tardi.";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Codice di sicurezza errato! Riprovare!";

==> evolution-1.4.20.zip: evolution-1.4.20/manager/includes/lang/errormsg/italian.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language Italian
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Nessun errore.";
$_lang["An error occured!"] = "Si è verificato un errore!";
$_lang["You don't have enough privileges for this action!"] = "Non avete i diritti necessari per effettuare questa operazione!";
$_lang["ID passed in request is NaN!"] = "L'ID passato nella richiesta è NaN!";
$_lang["The document is locked!"] = "Il documento è bloccato!";
$_lang["Too many results returned from database!"] = "Sono stati trovati troppi risultati nel database!";
$_lang["Not enough/ no results returned from database!"] = "Sono stati trovati pochi risultati (o nessuno) nel database!";
$_lang["Couldn't find parent document's name!"] = "Impossibile trovare il nome del documento genitore!";
$_lang["Logging error!"] = "Errore nell'accesso!";
$_lang["Table to optimise not found in request!"] = "Impossibile trovare la tabella da ottimizzare!";
$_lang["No settings found in request!"] = "La richiesta non contiene impostazioni!";
$_lang["The document must have a title!"] = "Il documento deve avere un titolo!";
$_lang["No user selected as recipient of this message!"] = "Non è stato selezionato l'utente a cui inviare questo messaggio!";
$_lang["No group selected as recipient of this message!"] = "Non è stato selezionato il gruppo a cui inviare questo messaggio!";
$_lang["The document was not found!"] = "Impossibile trovare il documento!";
$_lang["Double action (GET & POST) posted!"] = "E' stata inviata una doppia azione (GET e POST)!";
$_lang["Document cannot be it's own parent!"] = "Il documento non può essere genitore di se stesso!";
$_lang["Document's ID not passed in request!"] = "Nella richiesta manca l'ID del documento!";
$_lang["New parent not set in request!"] = "Nella richiesta non è stato indicato il nuovo genitore!";
$_lang["don't know the user!" ] = "Nome utente o password errati inseriti o sei stato bloccato!";
$_lang["wrong password!"] = "Nome utente o password errati inseriti o sei stato bloccato!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Nome utente o password errati inseriti o sei stato bloccato!";
$_lang["You are blocked and cannot log in!"] = "Nome utente o password errati inseriti o sei stato bloccato!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Nome utente o password errati inseriti o sei stato bloccato!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Codice di sicurezza errato! Riprovare!";
